# ufs2arco
Tools for converting Unified Forecast System (UFS) output to Analysis Ready, Cloud Optimized (ARCO) format

## Installation


### Installation from pip

```bash
pip install ufs2arco
```

### Installation from GitHub

To obtain the latest development version, clone
[the repository](https://github.com/NOAA-PSL/ufs2arco>)
and install it as follows

```bash
git clone https://github.com/NOAA-PSL/ufs2arco.git
cd ufs2arco
pip install -e .
```
